@@ -79,7 +79,7 @@ namespace Gwenview
 {
 #undef ENABLE_LOG
 #undef LOG
-//#define ENABLE_LOG
+// #define ENABLE_LOG
 #ifdef ENABLE_LOG
 #define LOG(x) // qCDebug(GWENVIEW_LIB_LOG) << x
 #else
@@ -396,7 +396,7 @@ struct DocumentViewPrivate {
             mDrag->deleteLater();
         }
         mDrag = new QDrag(q);
-        const auto itemList = KFileItemList({q->document()->url()});
+        const auto itemList = KFileItemList({KFileItem(q->document()->url())});
         auto *mimeData = MimeTypeUtils::selectionMimeData(itemList, MimeTypeUtils::DropTarget);
         KUrlMimeData::exportUrlsToPortal(mimeData);
         mDrag->setMimeData(mimeData);
@@ -735,7 +735,7 @@ void DocumentView::zoomContinuous(int delta, QPointF center)
     const qreal currentZoom = d->mAdapter->zoom();
 
     // multiplies by sqrt(2) for every mouse wheel step
-    const qreal newZoom = currentZoom * pow(2, 0.5 * float(delta)/QWheelEvent::DefaultDeltasPerStep);
+    const qreal newZoom = currentZoom * pow(2, 0.5 * float(delta) / QWheelEvent::DefaultDeltasPerStep);
     d->setZoom(newZoom, center);
     return;
 }
@@ -857,15 +857,22 @@ void DocumentView::resizeEvent(QGraphicsSceneResizeEvent *event)
 
 void DocumentView::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
-    QGraphicsWidget::mousePressEvent(event);
-
     if (d->mAdapter->canZoom() && event->button() == Qt::MiddleButton) {
         if (event->modifiers() == Qt::NoModifier) {
+            event->accept();
             toggleZoomToFit();
         } else if (event->modifiers() == Qt::SHIFT) {
+            event->accept();
             toggleZoomToFill();
         }
     }
+
+    // Don't let (presumably double click handling in) the superclass swallow the second of two
+    // quickly following middle clicks, preventing a fast toggle & toggle again. We wouldn't even
+    // get a double click event - handling that could be somewhat cleaner.
+    if (!event->isAccepted()) {
+        QGraphicsWidget::mousePressEvent(event);
+    }
 }
 
 void DocumentView::wheelEvent(QGraphicsSceneWheelEvent *event)
